@@ -13,7 +13,7 @@ import numpy as np
 import xarray as xr
 from itertools import chain
 import pywapor.general.levels as levels
-
+from pywapor.enhancers.smooth.whittaker import whittaker_smoothing
 
 def main(dss, sources, folder, general_enhancers, example_t_vars = ["lst"]):
     """Aligns the datetimes in de `dss` xr.Datasets with the datetimes of the 
@@ -67,6 +67,12 @@ def main(dss, sources, folder, general_enhancers, example_t_vars = ["lst"]):
         spatial_interp = config["spatial_interp"]
         temporal_interp = config["temporal_interp"]
 
+        if isinstance(temporal_interp, dict):
+            kwargs = temporal_interp.copy()
+            temporal_interp = kwargs.pop("method")
+        else:
+            kwargs = {}
+
         # Align pixels of different products for a single variable together.
         dss_part = [ds[[var]] for ds in dss.values() if var in ds.data_vars]
         if len(dss_part) > 1:
@@ -77,7 +83,7 @@ def main(dss, sources, folder, general_enhancers, example_t_vars = ["lst"]):
         cleanup.append(temp_files1)
 
         # Combine different source_products (along time dimension).
-        ds = xr.combine_nested(dss1, concat_dim = "time").sortby("time").chunk(chunks).squeeze()
+        ds = xr.combine_nested(dss1, concat_dim = "time").chunk(chunks).sortby("time").squeeze()
 
         if var in example_t_vars:
             if "time" not in ds[var].dims:
@@ -86,19 +92,40 @@ def main(dss, sources, folder, general_enhancers, example_t_vars = ["lst"]):
                 example_time = ds["time"]
             else:
                 example_time = xr.concat([example_time, ds["time"]], dim = "time").drop_duplicates("time").sortby("time")
-            dss2[var] = ds
-        elif "time" in ds[var].dims:
-            ds = ds.interpolate_na(dim = "time", method = temporal_interp).ffill("time").bfill("time")
-            lbl = f"Aligning times in `{var}` ({ds.time.size}) with `{'` and `'.join(example_t_vars)}` ({example_time.time.size}, {temporal_interp})."
-            if not ds.time.equals(example_time):
-                ds = ds.interp_like(example_time, method = temporal_interp)
+        else:
+            ...
+
+        if "time" in ds[var].dims and not isinstance(temporal_interp, type(None)):
+            orig_time_size = ds["time"].size
+            if temporal_interp == "whittaker":
+                if (not ds.time.equals(example_time)) and (not var in example_t_vars):
+                    new_x = example_time.values
+                else:
+                    new_x = None
+                if "weights" in kwargs.keys():
+                    ds["sensor"] = xr.combine_nested([xr.ones_like(x.time.astype(int)) * i for i, x in enumerate(dss1)], concat_dim="time").sortby("time")
+                    source_legend = {str(i): os.path.split(x.encoding["source"])[-1].replace(".nc", "") for i, x in enumerate(dss1)}
+                    ds["sensor"] = ds["sensor"].assign_attrs(source_legend)
+                ds = whittaker_smoothing(ds, var, chunks = chunks, new_x = new_x, **kwargs)
+                ds = ds.rename_vars({f"{var}_smoothed": var})
+            else:
+                if not ds.time.equals(example_time):
+                    new_coords = xr.concat([ds.time, example_time], dim = "time").drop_duplicates("time").sortby("time")
+                    ds = ds.reindex_like(new_coords).chunk(chunks)
+                ds = ds.interpolate_na(dim = "time", method = temporal_interp, **kwargs).sel(time = example_time)
+
+            lbl = f"Aligning times in `{var}` ({orig_time_size}) with `{'` and `'.join(example_t_vars)}` ({example_time.time.size}, {temporal_interp})."
             dst_path = os.path.join(folder, f"{var}_i.nc")
             ds = save_ds(ds, dst_path, chunks = chunks, encoding = "initiate", label = lbl)
-            dss2[var] = ds
-            cleanup.append([ds])
+            log.add().info(f"> shape: {ds[var].shape}, kwargs: {list(kwargs.keys())}.").sub()
+            # cleanup.append([ds])
         else:
-            # Add time-invariant data as is.
-            dss2[var] = ds
+            ...
+
+        # Set dimension order.
+        ds = ds.transpose(*sorted(list(ds.dims.keys()), key = lambda e: ["time", "y", "x"].index(e)))
+
+        dss2[var] = ds
 
     # Apply variable specific enhancers
     variables = levels.find_setting(sources, "variable_enhancers")
@@ -111,6 +138,8 @@ def main(dss, sources, folder, general_enhancers, example_t_vars = ["lst"]):
     if len(example_source) == 1:
         example_ds = dss[example_source[0]]
         log_example_ds(example_ds)
+    elif len(example_source) == 0:
+        example_ds = None
     else:
         log.warning(f"--> Multiple example datasets found, selecting lowest resolution.")
         example_ds = None
